@@ -1,4 +1,5 @@
-# $Id: Currency.pm 1767 2007-03-22 00:07:33Z claco $
+# $Id: Currency.pm 1806 2007-04-19 00:10:05Z claco $
+## no critic
 package Handel::Compat::Currency;
 use strict;
 use warnings;
@@ -102,13 +103,15 @@ __END__
 
 =head1 NAME
 
-Handel::Currency - Price container to do currency conversion/formatting
+Handel::Compat::Currency - Price container to do currency conversion/formatting
 
 =head1 SYNOPSIS
 
-    use Handel::Currency;
+    use Handel::Compat::Currency;
 
-    my $curr = Handel::Currenct-new(1.2);
+    MyStorage->currency_class('Handel::Compt::Currency');
+
+    my $curr = Handel::Currency->new(1.2);
     print $curr->format();          # 1.20 USD
     print $curr->format('CAD');     # 1.20 CAD
     print $curr->format(undef, 'FMT_SYMBOL');   # $1.20
@@ -118,9 +121,8 @@ Handel::Currency - Price container to do currency conversion/formatting
 
 =head1 DESCRIPTION
 
-The C<Handel::Currency> module provides basic currency formatting within
-Handel. It can be used separately to format any number into a more friendly
-format:
+The Handel::Currency module provides basic currency formatting within Handel.
+It can be used separately to format any number into a more friendly format:
 
     my $price = 1.23;
     my $currency = Handel::Currency->new($price);
@@ -130,7 +132,7 @@ format:
 A new Handel::Currency object is automatically returned within the shopping
 cart when calling C<subtotal>, C<total>, and C<price> as an lvalue:
 
-    my $cart = Handel::Cart->load({id => '11111111-1111-1111-1111-111111111111'});
+    my $cart = Handel::Cart->search({id => '11111111-1111-1111-1111-111111111111'});
 
     print $cart->subtotal;              # 12.9
     print $cart->subtotal->format();    # 12.90 USD
@@ -142,68 +144,146 @@ based price.
 
 =head2 new
 
+=over
+
+=item Arguments: $price [, $code, $formatoptions]
+
+=back
+
 The create a new Handel::Currency instance, simply call C<new> and pass in the
 price to be formatted:
 
     my $currency = Handel::Currency->new(10.23);
 
+You can also pass in the default currency code and/or currency format to be used.
+
 =head1 METHODS
 
-=head2 format([$code, $options])
+=head2 code
 
-The C<format> method returns the freshly formatted price in a currency and
-format declared in C<Locale::Currency::Format>. If no currency code or
-format are specified, the defaults values from C<Handel::ConfigReader> are
-used. Currently those defaults are C<USD> and C<FMT_STANDARD>.
+=over
+
+=item Arguments: $code
+
+=back
+
+Gets/sets the three letter currency code for the current currency object.
+
+C<code> throws a L<Handel::Exception::Argument|Handel::Exception::Argument>
+if C<code> isn't a valid currency code.
+
+=head2 convert
+
+=over
+
+=item Arguments: $from, $to [, $format, $formatoptions]
+
+=back
+
+If no C<from> or C<formatoptions> is specified, the options passed to C<new>
+and then C<HandelCurrencyCode> and C<HandelCurrencyFormat>  will be used instead.
+
+C<convert> throws a L<Handel::Exception::Argument|Handel::Exception::Argument>
+if C<from> or C<to> aren't valid currency codes.
+
+If C<format> is true, the result of the conversion will also be formatted
+using the formatting options given or the default in C<new> and then
+C<HandelCurrencyFormat>.
+
+You can also simply chain the C<convert> call into a C<format> call.
+
+    my $price = Handel::Currency->new(1.25);
+    print $price->convert('USD', 'CAD')->format;
+
+=head2 converter_class
+
+=over
+
+=item Arguments: $converter_class
+
+=back
+
+Gets/sets the converter class to be used when converting currency numbers.
+
+    __PACKAGE__->currency_class('MyCurrencyConverter');
+
+The converter class can be any class that supports the following method
+signature:
+
+    sub convert {
+        my ($self, $price, $from, $to) = @_;
+
+        return $converted_price;
+    };
+
+A L<Handel::Exception|Handel::Exception> exception will be thrown if the
+specified class can not be loaded.
+
+=head2 format
+
+=over
+
+=item Arguments: $code [, $options]
+
+=back
+
+Returns the freshly formatted price in a currency and format declared in
+L<Locale::Currency::Format|Locale::Currency::Format>. If no currency code or
+format are specified, the defaults values from C<new> and then
+C<Handel::ConfigReader> are used. Currently those defaults are C<USD> and
+C<FMT_STANDARD>.
 
 It is also acceptable to specify different default values.
 See L</"CONFIGURATION"> and C<Handel::ConfigReader> for further details.
 
-In situations where C<Locale::Currency::Format> isn't installed, C<format>
-simply returns the price in it's original format no harm no foul.
+C<format> throws a L<Handel::Exception::Argument|Handel::Exception::Argument>
+if C<code> isn't a valid currency code.
 
-C<format> throws a C<Handel::Exception::Argument> if C<code> isn't a valid
-currency code.
+=head2 name
 
-=head2 convert($from, $to [, $format, $options])
+=over
 
-The C<convert> method converts the given price from one currency to another
-using C<Finance::Currency::Convert::WebserviceX>.
+=item Arguments $code
 
-In situations where C<Finance::Currency::Convert::WebserviceX> isn't installed,
-C<convert> simply returns undef.
+=back
 
-If no C<from> is specified, C<HandelCurrencyCode> below will be used instead.
+Returns the currency name for the specified currency code. If no currency code
+is specified, the currency code for the current object will be used. If that
+too is not specified, the code set in C<HandelCurrencyCode> will be used.
 
-C<convert> throws a C<Handel::Exception::Argument> if C<from> or C<to> aren't
-valid currency codes.
+C<name> throws a L<Handel::Exception::Argument|Handel::Exception::Argument>
+if C<code> isn't a valid currency code.
 
-If C<$format> is true, the result of the conversion will also be formatted
-using the formatting C<options> given or the default in
-C<HandelCurrencyFormat>.
+=head2 stringify
+
+Returns C<value> in scalar context. For now, this returns the same thing that
+was passed to C<new>. This maybe change in the future.
 
 =head2 value
 
-Returns the original value passed to new.
+Returns the original price value given to C<new>. Always use this instead of
+relying on stringification when deflating currency objects in DBIx::Class
+schemas.
 
 =head1 CONFIGURATION
 
 =head2 HandelCurrencyCode
 
 This sets the default currency code used when no code is passed into C<format>.
-See C<Locale::Currency::Format> for all available currency codes. The default
-code is USD.
+See L<Locale::Currency::Format|Locale::Currency::Format> for all available
+currency codes. The default code is USD.
 
 =head2 HandelCurrencyFormat
 
 This sets the default options used to format the price. See
-C<Locale::Currency::Format> for all available currency codes. The default
-format used is C<FMT_STANDARD>. Just like in C<Locale::Currency::Format>,
-you can combine options using C<|>.
+L<Locale::Currency::Format|Locale::Currency::Format> for all available currency
+codes. The default format used is C<FMT_STANDARD>. Just like in
+Locale::Currency::Format, you can combine options using C<|>.
 
 =head1 SEE ALSO
 
-L<Locale::Currency::Format>, L<Finance::Currency::Convert::WebserviceX>
+L<Locale::Currency>, L<Locale::Currency::Format>,
+L<Finance::Currency::Convert::WebserviceX>
 
 =head1 AUTHOR
 
