@@ -1,4 +1,4 @@
-# $Id: Result.pm 1408 2006-09-08 23:26:08Z claco $
+# $Id: Result.pm 1618 2006-12-13 03:46:25Z claco $
 package Handel::Storage::DBIC::Result;
 use strict;
 use warnings;
@@ -15,6 +15,12 @@ sub discard_changes {
     return shift->storage_result->discard_changes(@_);
 };
 
+sub has_column {
+    my ($self, $column) = @_;
+
+    return $self->storage_result->has_column_loaded($column);
+};
+
 sub update {
     return shift->storage_result->update(@_);
 };
@@ -69,6 +75,16 @@ storage.
 
 Discards all changes made since the last successful update.
 
+=head2 has_column
+
+=over
+
+=item Arguments: $column
+
+=back
+
+Returns true if the column exists in the current result object.
+
 =head2 update
 
 =over
@@ -90,7 +106,7 @@ Updates the current result with the data specified.
 
 =head1 SEE ALSO
 
-L<Handel::Storage::Result>
+L<Handel::Storage::Result>, L<DBIx::Class>
 
 =head1 AUTHOR
 
