@@ -1,11 +1,11 @@
-# $Id: Cart.pm 1300 2006-07-08 01:12:16Z claco $
+# $Id: Cart.pm 1409 2006-09-09 21:16:54Z claco $
 package Handel::Subclassing::Cart;
 use strict;
 use warnings;
-use base 'Handel::Cart';
+use base qw/Handel::Cart/;
 
+__PACKAGE__->item_class('Handel::Subclassing::CartItem');
 __PACKAGE__->storage->add_columns('custom');
-__PACKAGE__->storage->item_class('Handel::Subclassing::CartItem');
 __PACKAGE__->create_accessors;
 
 1;
